use std::io::Result;
use std::path::{Path, PathBuf};
use std::{fs, io};

fn guess_video_path(path: &Path) -> Result<PathBuf> {
    let mut largest_size = 0;
    let mut largest_file = PathBuf::from(path);
    for entry in fs::read_dir(path)? {
        let entry_path = entry?.path().canonicalize()?;
        if entry_path.is_dir() {
            continue;
        }

        let size = entry_path.metadata()?.len();
        if size > largest_size {
            largest_size = size;
            largest_file = entry_path.into();
        }
    }

    Ok(largest_file)
}

pub fn merge_video_from_path(path: &Path) -> Result<()> {
    let video_path = guess_video_path(path)?;
    let video_name = video_path.file_name().unwrap().to_str().unwrap();
    let video_extension = video_path.extension().unwrap();

    let audio_name = format!("{}.m4a", &video_name[..video_name.len() - video_extension.len() - 1]);
    let audio_path = video_path.parent().unwrap().join(audio_name);
    if !audio_path.exists() {
        return Err(io::Error::new(io::ErrorKind::NotFound, "Audio file does not exist"));
    }

    println!("Merging video from {:?}", audio_path);
    println!("Merging video {:?}", video_name);

    Ok(())
}
